.. _policy-configuration:

--------------------------
Trove Policy Configuration
--------------------------

The following is an overview of all available policies in Aodh.

For a sample policy file refer to the :ref:`trove-policy-file` or
run ``tox -egenpolicy`` in the repo folder and the new file will
be located in etc/trove/policy.yaml.sample

.. show-policy::
   :config-file: tools/trove-policy-generator.conf
